@@ -14,6 +14,7 @@
 
 import ZettlrCommand from './zettlr-command'
 import sanitize from 'sanitize-filename'
+import path from 'path'
 
 export default class DirRename extends ZettlrCommand {
   constructor (app: any) {
@@ -26,26 +27,38 @@ export default class DirRename extends ZettlrCommand {
    * @param  {Object} arg An object containing hash of containing and name of new dir.
    */
   async run (evt: string, arg: any): Promise<boolean> {
-    let sourceDir = this._app.findDir(arg.hash)
+    const sourceDir = this._app.findDir(arg.path)
     if (sourceDir === null) {
       global.log.error('Could not rename directory: Not found.')
       return false
     }
 
     const sanitizedName = sanitize(arg.name, { replacement: '-' })
+    const isRootDir = sourceDir.parent === null
+    const oldPath = sourceDir.path
+    const newPath = path.join(sourceDir.dir, sanitizedName)
 
     try {
       await this._app.getFileSystem().renameDir(sourceDir, sanitizedName)
-    } catch (e) {
-      console.error(e)
+    } catch (err: any) {
+      console.error(err)
       this._app.prompt({
         type: 'error',
-        title: e.name,
-        message: e.message
+        title: err.name,
+        message: err.message
       })
       return false
     }
 
+    // At this point the directory has been correctly renamed. However, if we
+    // just renamed a root directory, we have to exchange the old path for the
+    // new one in the config as well.
+    if (isRootDir) {
+      global.config.removePath(oldPath)
+      global.config.addPath(newPath)
+      global.log.info(`[DirRename Command] Exchanged ${oldPath} with ${newPath} in config`)
+    }
+
     return true
   }
 }
