@@ -25,10 +25,11 @@ export default class DirSetIcon extends ZettlrCommand {
     * @param  {Object} arg An object containing both a hash and an icon
     */
   async run (evt: string, arg: any): Promise<boolean> {
-    let dir = this._app.findDir(arg.hash)
-    if (dir === null) return false
+    let dir = this._app.findDir(arg.path)
 
-    console.log('Setting directory icon', arg.icon)
+    if (dir === null) {
+      return false
+    }
 
     await this._app.getFileSystem().setDirectorySetting(dir, { 'icon': arg.icon })
     return true
