@@ -13,7 +13,6 @@
  */
 
 import ZettlrCommand from './zettlr-command'
-import expandOptionObject from '../../common/util/expand-option-object'
 
 export default class UpdateProjectProperties extends ZettlrCommand {
   constructor (app: any) {
@@ -28,13 +27,13 @@ export default class UpdateProjectProperties extends ZettlrCommand {
   async run (evt: string, arg: any): Promise<void> {
     // The properties come from the renderer with dot notation, but the action
     // expects them already in their expanded state.
-    let expanded = expandOptionObject(arg.properties)
+    // let expanded = expandOptionObject(arg.properties)
     // Find the directory, and apply the properties to it!
-    let dir = this._app.findDir(arg.hash)
+    let dir = this._app.findDir(arg.path)
     if (dir !== null) {
-      await this._app.getFileSystem().updateProject(dir, expanded)
+      await this._app.getFileSystem().updateProject(dir, arg.properties)
     } else {
-      global.log.warning(`Could not update project properties for ${String(arg.hash)}: No directory found!`)
+      global.log.warning(`Could not update project properties for ${String(arg.path)}: No directory found!`)
     }
   }
 }
