@@ -18,7 +18,8 @@
 import EventEmitter from 'events'
 import path from 'path'
 import chokidar from 'chokidar'
-import { CodeFileDescriptor, CodeFileMeta, MDFileDescriptor, MDFileMeta } from '../fsal/types'
+import { CodeFileDescriptor, MDFileDescriptor } from '@dts/main/fsal'
+import { CodeFileMeta, MDFileMeta } from '@dts/common/fsal'
 import { FSALCodeFile, FSALFile } from '../fsal'
 import { codeFileExtensions, mdFileExtensions } from '@common/get-file-extensions'
 import generateFilename from '@common/util/generate-filename'
